quantizationtools.SearchTree
============================

.. abjad-lineage:: abjad.tools.quantizationtools.SearchTree.SearchTree.SearchTree

.. autoclass:: abjad.tools.quantizationtools.SearchTree.SearchTree.SearchTree
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.quantizationtools.SearchTree.SearchTree.SearchTree.default_definition
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.SearchTree.SearchTree.SearchTree.definition
   :noindex:

.. autoattribute:: abjad.tools.quantizationtools.SearchTree.SearchTree.SearchTree.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.quantizationtools.SearchTree.SearchTree.SearchTree.__call__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SearchTree.SearchTree.SearchTree.__eq__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SearchTree.SearchTree.SearchTree.__ge__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SearchTree.SearchTree.SearchTree.__getstate__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SearchTree.SearchTree.SearchTree.__gt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SearchTree.SearchTree.SearchTree.__le__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SearchTree.SearchTree.SearchTree.__lt__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SearchTree.SearchTree.SearchTree.__ne__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SearchTree.SearchTree.SearchTree.__repr__
   :noindex:

.. automethod:: abjad.tools.quantizationtools.SearchTree.SearchTree.SearchTree.__setstate__
   :noindex:
